# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ProcedureSignature(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hard_hash': 'str',
        'is_library': 'bool',
        'status': 'str',
        'coverage': 'float',
        'byte_counts': 'list[int]',
        'instr_counts': 'list[int]',
        'block_counts': 'list[int]',
        'occurrence_counts': 'int',
        'procedure_names': 'list[str]',
        'name_counts': 'int',
        'signature': 'list[list[str]]',
        'example_procedure': 'list[list[str]]'
    }

    attribute_map = {
        'hard_hash': 'hard_hash',
        'is_library': 'is_library',
        'status': 'status',
        'coverage': 'coverage',
        'byte_counts': 'byte_counts',
        'instr_counts': 'instr_counts',
        'block_counts': 'block_counts',
        'occurrence_counts': 'occurrence_counts',
        'procedure_names': 'procedure_names',
        'name_counts': 'name_counts',
        'signature': 'signature',
        'example_procedure': 'example_procedure'
    }

    def __init__(self, hard_hash=None, is_library=None, status=None, coverage=None, byte_counts=None, instr_counts=None, block_counts=None, occurrence_counts=None, procedure_names=None, name_counts=None, signature=None, example_procedure=None):  # noqa: E501
        """ProcedureSignature - a model defined in Swagger"""  # noqa: E501

        self._hard_hash = None
        self._is_library = None
        self._status = None
        self._coverage = None
        self._byte_counts = None
        self._instr_counts = None
        self._block_counts = None
        self._occurrence_counts = None
        self._procedure_names = None
        self._name_counts = None
        self._signature = None
        self._example_procedure = None
        self.discriminator = None

        if hard_hash is not None:
            self.hard_hash = hard_hash
        if is_library is not None:
            self.is_library = is_library
        if status is not None:
            self.status = status
        if coverage is not None:
            self.coverage = coverage
        if byte_counts is not None:
            self.byte_counts = byte_counts
        if instr_counts is not None:
            self.instr_counts = instr_counts
        if block_counts is not None:
            self.block_counts = block_counts
        if occurrence_counts is not None:
            self.occurrence_counts = occurrence_counts
        if procedure_names is not None:
            self.procedure_names = procedure_names
        if name_counts is not None:
            self.name_counts = name_counts
        if signature is not None:
            self.signature = signature
        if example_procedure is not None:
            self.example_procedure = example_procedure

    @property
    def hard_hash(self):
        """Gets the hard_hash of this ProcedureSignature.  # noqa: E501

        The proc hash for this procedure group.  # noqa: E501

        :return: The hard_hash of this ProcedureSignature.  # noqa: E501
        :rtype: str
        """
        return self._hard_hash

    @hard_hash.setter
    def hard_hash(self, hard_hash):
        """Sets the hard_hash of this ProcedureSignature.

        The proc hash for this procedure group.  # noqa: E501

        :param hard_hash: The hard_hash of this ProcedureSignature.  # noqa: E501
        :type: str
        """
        if hard_hash is not None and not re.search(r'[a-fA-F0-9]{32}', hard_hash):  # noqa: E501
            raise ValueError(r"Invalid value for `hard_hash`, must be a follow pattern or equal to `/[a-fA-F0-9]{32}/`")  # noqa: E501

        self._hard_hash = hard_hash

    @property
    def is_library(self):
        """Gets the is_library of this ProcedureSignature.  # noqa: E501

        Is one or more procedures in this group marked as a library function?  # noqa: E501

        :return: The is_library of this ProcedureSignature.  # noqa: E501
        :rtype: bool
        """
        return self._is_library

    @is_library.setter
    def is_library(self, is_library):
        """Sets the is_library of this ProcedureSignature.

        Is one or more procedures in this group marked as a library function?  # noqa: E501

        :param is_library: The is_library of this ProcedureSignature.  # noqa: E501
        :type: bool
        """

        self._is_library = is_library

    @property
    def status(self):
        """Gets the status of this ProcedureSignature.  # noqa: E501

        Indicates the current status of the signature. Must be one of the following -    empty - No procedure added to the group   clone - All the procedures in the group are clones   variant-{blocks,instr,bytes} - Procedures had a different number of {blocks,instr,bytes}   variant-alignment - Procedures have the same number of {blocks,instr,bytes}, but something else isn't lining up  # noqa: E501

        :return: The status of this ProcedureSignature.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ProcedureSignature.

        Indicates the current status of the signature. Must be one of the following -    empty - No procedure added to the group   clone - All the procedures in the group are clones   variant-{blocks,instr,bytes} - Procedures had a different number of {blocks,instr,bytes}   variant-alignment - Procedures have the same number of {blocks,instr,bytes}, but something else isn't lining up  # noqa: E501

        :param status: The status of this ProcedureSignature.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def coverage(self):
        """Gets the coverage of this ProcedureSignature.  # noqa: E501

        Percentage of given binaries this procedure is in. Will be between 0 and 1 inclusive.  # noqa: E501

        :return: The coverage of this ProcedureSignature.  # noqa: E501
        :rtype: float
        """
        return self._coverage

    @coverage.setter
    def coverage(self, coverage):
        """Sets the coverage of this ProcedureSignature.

        Percentage of given binaries this procedure is in. Will be between 0 and 1 inclusive.  # noqa: E501

        :param coverage: The coverage of this ProcedureSignature.  # noqa: E501
        :type: float
        """

        self._coverage = coverage

    @property
    def byte_counts(self):
        """Gets the byte_counts of this ProcedureSignature.  # noqa: E501


        :return: The byte_counts of this ProcedureSignature.  # noqa: E501
        :rtype: list[int]
        """
        return self._byte_counts

    @byte_counts.setter
    def byte_counts(self, byte_counts):
        """Sets the byte_counts of this ProcedureSignature.


        :param byte_counts: The byte_counts of this ProcedureSignature.  # noqa: E501
        :type: list[int]
        """

        self._byte_counts = byte_counts

    @property
    def instr_counts(self):
        """Gets the instr_counts of this ProcedureSignature.  # noqa: E501


        :return: The instr_counts of this ProcedureSignature.  # noqa: E501
        :rtype: list[int]
        """
        return self._instr_counts

    @instr_counts.setter
    def instr_counts(self, instr_counts):
        """Sets the instr_counts of this ProcedureSignature.


        :param instr_counts: The instr_counts of this ProcedureSignature.  # noqa: E501
        :type: list[int]
        """

        self._instr_counts = instr_counts

    @property
    def block_counts(self):
        """Gets the block_counts of this ProcedureSignature.  # noqa: E501


        :return: The block_counts of this ProcedureSignature.  # noqa: E501
        :rtype: list[int]
        """
        return self._block_counts

    @block_counts.setter
    def block_counts(self, block_counts):
        """Sets the block_counts of this ProcedureSignature.


        :param block_counts: The block_counts of this ProcedureSignature.  # noqa: E501
        :type: list[int]
        """

        self._block_counts = block_counts

    @property
    def occurrence_counts(self):
        """Gets the occurrence_counts of this ProcedureSignature.  # noqa: E501

        Number of ProcedureGenomics objects with the same hard_hash.  # noqa: E501

        :return: The occurrence_counts of this ProcedureSignature.  # noqa: E501
        :rtype: int
        """
        return self._occurrence_counts

    @occurrence_counts.setter
    def occurrence_counts(self, occurrence_counts):
        """Sets the occurrence_counts of this ProcedureSignature.

        Number of ProcedureGenomics objects with the same hard_hash.  # noqa: E501

        :param occurrence_counts: The occurrence_counts of this ProcedureSignature.  # noqa: E501
        :type: int
        """

        self._occurrence_counts = occurrence_counts

    @property
    def procedure_names(self):
        """Gets the procedure_names of this ProcedureSignature.  # noqa: E501


        :return: The procedure_names of this ProcedureSignature.  # noqa: E501
        :rtype: list[str]
        """
        return self._procedure_names

    @procedure_names.setter
    def procedure_names(self, procedure_names):
        """Sets the procedure_names of this ProcedureSignature.


        :param procedure_names: The procedure_names of this ProcedureSignature.  # noqa: E501
        :type: list[str]
        """

        self._procedure_names = procedure_names

    @property
    def name_counts(self):
        """Gets the name_counts of this ProcedureSignature.  # noqa: E501

        Number of unique procedures in this procedure group  # noqa: E501

        :return: The name_counts of this ProcedureSignature.  # noqa: E501
        :rtype: int
        """
        return self._name_counts

    @name_counts.setter
    def name_counts(self, name_counts):
        """Sets the name_counts of this ProcedureSignature.

        Number of unique procedures in this procedure group  # noqa: E501

        :param name_counts: The name_counts of this ProcedureSignature.  # noqa: E501
        :type: int
        """

        self._name_counts = name_counts

    @property
    def signature(self):
        """Gets the signature of this ProcedureSignature.  # noqa: E501


        :return: The signature of this ProcedureSignature.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this ProcedureSignature.


        :param signature: The signature of this ProcedureSignature.  # noqa: E501
        :type: list[list[str]]
        """

        self._signature = signature

    @property
    def example_procedure(self):
        """Gets the example_procedure of this ProcedureSignature.  # noqa: E501


        :return: The example_procedure of this ProcedureSignature.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._example_procedure

    @example_procedure.setter
    def example_procedure(self, example_procedure):
        """Sets the example_procedure of this ProcedureSignature.


        :param example_procedure: The example_procedure of this ProcedureSignature.  # noqa: E501
        :type: list[list[str]]
        """

        self._example_procedure = example_procedure

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProcedureSignature, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcedureSignature):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cythereal_magic.api_client import ApiClient


class CytherealMagicApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_file(self, filedata, **kwargs):  # noqa: E501
        """Upload a file for processing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file(filedata, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file filedata: Binary contents of the file (required)
        :param str filename: Name of the file being uploaded
        :param str password: If uploading a password protected zip, this field MUST contain the password. 
        :param int priority: Analysis priority. Higher priority files are analyzed first. Priorities higher than default may require additional privileges.
        :return: FileUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_file_with_http_info(filedata, **kwargs)  # noqa: E501
        else:
            (data) = self.create_file_with_http_info(filedata, **kwargs)  # noqa: E501
            return data

    def create_file_with_http_info(self, filedata, **kwargs):  # noqa: E501
        """Upload a file for processing  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file_with_http_info(filedata, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file filedata: Binary contents of the file (required)
        :param str filename: Name of the file being uploaded
        :param str password: If uploading a password protected zip, this field MUST contain the password. 
        :param int priority: Analysis priority. Higher priority files are analyzed first. Priorities higher than default may require additional privileges.
        :return: FileUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filedata', 'filename', 'password', 'priority']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'filedata' is set
        if ('filedata' not in params or
                params['filedata'] is None):
            raise ValueError("Missing the required parameter `filedata` when calling `create_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filename' in params:
            query_params.append(('filename', params['filename']))  # noqa: E501
        if 'password' in params:
            query_params.append(('password', params['password']))  # noqa: E501
        if 'priority' in params:
            query_params.append(('priority', params['priority']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'filedata' in params:
            local_var_files['filedata'] = params['filedata']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileUploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_file(self, file_hash, **kwargs):  # noqa: E501
        """Download a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_file(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_file_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.download_file_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def download_file_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Download a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_file_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `download_file`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `download_file`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/{file_hash}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_binary_genomics(self, file_hash, **kwargs):  # noqa: E501
        """Show the genomic features for a given binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_binary_genomics(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: BinaryGenomicsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_binary_genomics_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_binary_genomics_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_binary_genomics_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Show the genomic features for a given binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_binary_genomics_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: BinaryGenomicsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_binary_genomics" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_binary_genomics`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_binary_genomics`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/genomics/{file_hash}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BinaryGenomicsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_campaign_id(self, file_hash, **kwargs):  # noqa: E501
        """Get the campaign id for a binary.  # noqa: E501

        Useful for quickly getting the campaign_id for a binary.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_campaign_id(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: CampaignIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_campaign_id_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_campaign_id_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_campaign_id_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Get the campaign id for a binary.  # noqa: E501

        Useful for quickly getting the campaign_id for a binary.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_campaign_id_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: CampaignIdResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_campaign_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_campaign_id`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_campaign_id`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/reports/{file_hash}/campaign', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CampaignIdResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_info(self, file_hash, **kwargs):  # noqa: E501
        """Get file info and analysis status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: FileInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_info_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_info_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_file_info_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Get file info and analysis status  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: FileInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_file_info`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_file_info`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/{file_hash}/info/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_owned_files(self, **kwargs):  # noqa: E501
        """List files owned by the authenticated user.  # noqa: E501

        List files owned by the authenticated user.  This includes files uploaded by the user and files created from these originally uploaded files. Known issues:   - Upload date is based on the date *any* user uploaded the file, not specifically this user.   - If the user has uploaded a large amount of files (order of 100k), a query without the date     filter will cause the server to time out. The workaround is to filter by date.   - If the user has uploaded a large amount of files on any given date, filtering by this date     will still cause the server to timeout.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_owned_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str _date: Return uploads from the given date. If not provided, all owned files from startDate to endDate will be returned Specify date as `YYYY-MM-DD`. 
        :param str start_date: Return uploads from the given date until endDate. Specify date as `YYYY-MM-DD`. 
        :param str end_date: Return uploads from startDate until the given date. Specify date as `YYYY-MM-DD`. 
        :param bool public: Return files that are marked as public. This will return **only** public files, and ignore the user's files. 
        :param bool only_top_level: Will return only uploaded files (no children) when True. 
        :param float page: Page of results to retrieve. Starts at 1. If not provided, the first page of results will be returned. 
        :return: OwnedFilesListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_owned_files_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_owned_files_with_http_info(**kwargs)  # noqa: E501
            return data
    # Backwards compatibility.
    find_owned_files = get_owned_files

    def get_owned_files_with_http_info(self, **kwargs):  # noqa: E501
        """List files owned by the authenticated user.  # noqa: E501

        List files owned by the authenticated user.  This includes files uploaded by the user and files created from these originally uploaded files. Known issues:   - Upload date is based on the date *any* user uploaded the file, not specifically this user.   - If the user has uploaded a large amount of files (order of 100k), a query without the date     filter will cause the server to time out. The workaround is to filter by date.   - If the user has uploaded a large amount of files on any given date, filtering by this date     will still cause the server to timeout.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_owned_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str _date: Return uploads from the given date. If not provided, all owned files from startDate to endDate will be returned Specify date as `YYYY-MM-DD`. 
        :param str start_date: Return uploads from the given date until endDate. Specify date as `YYYY-MM-DD`. 
        :param str end_date: Return uploads from startDate until the given date. Specify date as `YYYY-MM-DD`. 
        :param bool public: Return files that are marked as public. This will return **only** public files, and ignore the user's files. 
        :param bool only_top_level: Will return only uploaded files (no children) when True. 
        :param float page: Page of results to retrieve. Starts at 1. If not provided, the first page of results will be returned. 
        :return: OwnedFilesListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_date', 'start_date', 'end_date', 'public', 'only_top_level', 'page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_owned_files" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_date' in params:
            query_params.append(('date', params['_date']))  # noqa: E501
        if 'start_date' in params:
            query_params.append(('start_date', params['start_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('end_date', params['end_date']))  # noqa: E501
        if 'public' in params:
            query_params.append(('public', params['public']))  # noqa: E501
        if 'only_top_level' in params:
            query_params.append(('only_top_level', params['only_top_level']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OwnedFilesListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_procedure_genomics(self, file_hash, proc_rva, **kwargs):  # noqa: E501
        """Show the genomic features for a given procedure.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_procedure_genomics(file_hash, proc_rva, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param str proc_rva: The RVA of the procedure to find similarities with. Formatted 0xnnnn (required)
        :return: ProcedureGenomicsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_procedure_genomics_with_http_info(file_hash, proc_rva, **kwargs)  # noqa: E501
        else:
            (data) = self.get_procedure_genomics_with_http_info(file_hash, proc_rva, **kwargs)  # noqa: E501
            return data

    def get_procedure_genomics_with_http_info(self, file_hash, proc_rva, **kwargs):  # noqa: E501
        """Show the genomic features for a given procedure.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_procedure_genomics_with_http_info(file_hash, proc_rva, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param str proc_rva: The RVA of the procedure to find similarities with. Formatted 0xnnnn (required)
        :return: ProcedureGenomicsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash', 'proc_rva']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_procedure_genomics" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_procedure_genomics`")  # noqa: E501
        # verify the required parameter 'proc_rva' is set
        if ('proc_rva' not in params or
                params['proc_rva'] is None):
            raise ValueError("Missing the required parameter `proc_rva` when calling `get_procedure_genomics`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_procedure_genomics`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501
        if 'proc_rva' in params:
            path_params['proc_rva'] = params['proc_rva']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/genomics/{file_hash}/{proc_rva}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProcedureGenomicsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_report(self, file_hash, **kwargs):  # noqa: E501
        """Get the Magic report for a binary.  # noqa: E501

        Includes most of the report information. Does not include magic matches for performance reasons.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicReportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_report_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Get the Magic report for a binary.  # noqa: E501

        Includes most of the report information. Does not include magic matches for performance reasons.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicReportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_report`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_report`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/reports/{file_hash}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MagicReportResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_report_categories(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC categories for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_categories(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicCategoriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_categories_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_categories_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    # Backwards compatibility
    find_report_categories = get_report_categories

    def get_report_categories_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC categories for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_categories_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicCategoriesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_categories" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_report_categories`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_report_categories`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/reports/{file_hash}/categories/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MagicCategoriesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_report_labels(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC labels report for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_labels(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicLabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_labels_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_labels_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def get_report_labels_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC labels report for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_labels_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :return: MagicLabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_labels" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_report_labels`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_report_labels`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/reports/{file_hash}/labels/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MagicLabelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_report_matches(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC matches for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_matches(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param float threshold: Only similarity matches at value equal or above threshold will be considered.  MUST be in range [0, 1]. Defaults to 0.7.
        :param int limit: Number of matches to return per call
        :param int page: Number of pages per (limit) to skip
        :return: MagicMatchesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_report_matches_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_report_matches_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    # Backwards compatibility
    find_report_matches = get_report_matches

    def get_report_matches_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Retrieve the MAGIC matches for a binary.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_report_matches_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param float threshold: Only similarity matches at value equal or above threshold will be considered.  MUST be in range [0, 1]. Defaults to 0.7.
        :param int limit: Number of matches to return per call
        :param int page: Number of pages per (limit) to skip
        :return: MagicMatchesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash', 'threshold', 'limit', 'page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_report_matches" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_report_matches`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_report_matches`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []
        if 'threshold' in params:
            query_params.append(('threshold', params['threshold']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/reports/{file_hash}/matches/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MagicMatchesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_similar_binaries(self, file_hash, **kwargs):  # noqa: E501
        """Search for similar binaries.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_similar_binaries(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param float threshold: Similarity threshold, default 0.7.
        :param int limit: Number of matches to return per call
        :param int page: Number of pages per (limit) to skip
        :param str method: Method used to determine this procedure was similar with the query procedure.  Possible values are  - `semantic_hash` The semantics based hashes matched. - `semantic_similarity` The semantics of the binaries are similar. The semantic hashes may or may not match. 
        :return: BinarySimilarityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_similar_binaries_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.get_similar_binaries_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    # Backwards compatibility
    find_similar_binaries = get_similar_binaries

    def get_similar_binaries_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Search for similar binaries.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_similar_binaries_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param float threshold: Similarity threshold, default 0.7.
        :param int limit: Number of matches to return per call
        :param int page: Number of pages per (limit) to skip
        :param str method: Method used to determine this procedure was similar with the query procedure.  Possible values are  - `semantic_hash` The semantics based hashes matched. - `semantic_similarity` The semantics of the binaries are similar. The semantic hashes may or may not match. 
        :return: BinarySimilarityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash', 'threshold', 'limit', 'page', 'method']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_similar_binaries" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_similar_binaries`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_similar_binaries`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []
        if 'threshold' in params:
            query_params.append(('threshold', params['threshold']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'method' in params:
            query_params.append(('method', params['method']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/similarities/{file_hash}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BinarySimilarityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_similar_procedures(self, file_hash, proc_rva, **kwargs):  # noqa: E501
        """Search for procedures similar to a given procedure.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_similar_procedures(file_hash, proc_rva, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param str proc_rva: The RVA of the procedure to find similarities with. Formatted 0xnnnn (required)
        :param str method: Method used to determine this procedure was similar with the query procedure.  Possible values are  - `semantic_hash` Hashes based on the semantics of the procedures matches. 
        :return: ProcedureSimilarityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_similar_procedures_with_http_info(file_hash, proc_rva, **kwargs)  # noqa: E501
        else:
            (data) = self.get_similar_procedures_with_http_info(file_hash, proc_rva, **kwargs)  # noqa: E501
            return data

    # Backwards compatibility
    find_similar_procedures = get_similar_procedures

    def get_similar_procedures_with_http_info(self, file_hash, proc_rva, **kwargs):  # noqa: E501
        """Search for procedures similar to a given procedure.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_similar_procedures_with_http_info(file_hash, proc_rva, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param str proc_rva: The RVA of the procedure to find similarities with. Formatted 0xnnnn (required)
        :param str method: Method used to determine this procedure was similar with the query procedure.  Possible values are  - `semantic_hash` Hashes based on the semantics of the procedures matches. 
        :return: ProcedureSimilarityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash', 'proc_rva', 'method']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_similar_procedures" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `get_similar_procedures`")  # noqa: E501
        # verify the required parameter 'proc_rva' is set
        if ('proc_rva' not in params or
                params['proc_rva'] is None):
            raise ValueError("Missing the required parameter `proc_rva` when calling `get_similar_procedures`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `get_similar_procedures`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501
        if 'proc_rva' in params:
            path_params['proc_rva'] = params['proc_rva']  # noqa: E501

        query_params = []
        if 'method' in params:
            query_params.append(('method', params['method']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/similarities/{file_hash}/{proc_rva}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProcedureSimilarityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ping(self, **kwargs):  # noqa: E501
        """Check if server is responding to queries.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def ping_with_http_info(self, **kwargs):  # noqa: E501
        """Check if server is responding to queries.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ping" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ping/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def reprocess_file(self, file_hash, **kwargs):  # noqa: E501
        """Reprocess a previously uploaded file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reprocess_file(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param int priority: Analysis priority. Higher priority files are analyzed first. Priorities higher than default may require additional privileges.
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.reprocess_file_with_http_info(file_hash, **kwargs)  # noqa: E501
        else:
            (data) = self.reprocess_file_with_http_info(file_hash, **kwargs)  # noqa: E501
            return data

    def reprocess_file_with_http_info(self, file_hash, **kwargs):  # noqa: E501
        """Reprocess a previously uploaded file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.reprocess_file_with_http_info(file_hash, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str file_hash: A cryptographic hash of a file. Supported hashes are SHA1. (required)
        :param int priority: Analysis priority. Higher priority files are analyzed first. Priorities higher than default may require additional privileges.
        :return: SuccessResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_hash', 'priority']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method reprocess_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_hash' is set
        if ('file_hash' not in params or
                params['file_hash'] is None):
            raise ValueError("Missing the required parameter `file_hash` when calling `reprocess_file`")  # noqa: E501

        if 'file_hash' in params and not re.search(r'[a-fA-F0-9]{32}', params['file_hash']):  # noqa: E501
            raise ValueError("Invalid value for parameter `file_hash` when calling `reprocess_file`, must conform to the pattern `/[a-fA-F0-9]{32}/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'file_hash' in params:
            path_params['file_hash'] = params['file_hash']  # noqa: E501

        query_params = []
        if 'priority' in params:
            query_params.append(('priority', params['priority']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key_query_param']  # noqa: E501

        return self.api_client.call_api(
            '/files/{file_hash}/reprocess/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MagicReport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sha1': 'str',
        'sha256': 'str',
        'sha512': 'str',
        'md5': 'str',
        'unix_file_type': 'str',
        'object_class': 'str',
        'filename': 'list[str]',
        'first_seen': 'str',
        'is_owned': 'bool',
        'categories': 'MagicCategories',
        'labels': 'list[MagicLabel]',
        'tags': 'list[str]',
        'detection_stats': 'MagicReportDetectionStats',
        'av_names': 'list[str]',
        'campaign_id': 'str'
    }

    attribute_map = {
        'sha1': 'sha1',
        'sha256': 'sha256',
        'sha512': 'sha512',
        'md5': 'md5',
        'unix_file_type': 'unix_file_type',
        'object_class': 'object_class',
        'filename': 'filename',
        'first_seen': 'first_seen',
        'is_owned': 'is_owned',
        'categories': 'categories',
        'labels': 'labels',
        'tags': 'tags',
        'detection_stats': 'detection_stats',
        'av_names': 'av_names',
        'campaign_id': 'campaign_id'
    }

    def __init__(self, sha1=None, sha256=None, sha512=None, md5=None, unix_file_type=None, object_class=None, filename=None, first_seen=None, is_owned=None, categories=None, labels=None, tags=None, detection_stats=None, av_names=None, campaign_id=None):  # noqa: E501
        """MagicReport - a model defined in Swagger"""  # noqa: E501

        self._sha1 = None
        self._sha256 = None
        self._sha512 = None
        self._md5 = None
        self._unix_file_type = None
        self._object_class = None
        self._filename = None
        self._first_seen = None
        self._is_owned = None
        self._categories = None
        self._labels = None
        self._tags = None
        self._detection_stats = None
        self._av_names = None
        self._campaign_id = None
        self.discriminator = None

        if sha1 is not None:
            self.sha1 = sha1
        if sha256 is not None:
            self.sha256 = sha256
        if sha512 is not None:
            self.sha512 = sha512
        if md5 is not None:
            self.md5 = md5
        if unix_file_type is not None:
            self.unix_file_type = unix_file_type
        if object_class is not None:
            self.object_class = object_class
        if filename is not None:
            self.filename = filename
        if first_seen is not None:
            self.first_seen = first_seen
        if is_owned is not None:
            self.is_owned = is_owned
        if categories is not None:
            self.categories = categories
        if labels is not None:
            self.labels = labels
        if tags is not None:
            self.tags = tags
        if detection_stats is not None:
            self.detection_stats = detection_stats
        if av_names is not None:
            self.av_names = av_names
        if campaign_id is not None:
            self.campaign_id = campaign_id

    @property
    def sha1(self):
        """Gets the sha1 of this MagicReport.  # noqa: E501

        A SHA1 cryptographic hash  # noqa: E501

        :return: The sha1 of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this MagicReport.

        A SHA1 cryptographic hash  # noqa: E501

        :param sha1: The sha1 of this MagicReport.  # noqa: E501
        :type: str
        """
        if sha1 is not None and not re.search(r'[a-fA-F0-9]{40}', sha1):  # noqa: E501
            raise ValueError(r"Invalid value for `sha1`, must be a follow pattern or equal to `/[a-fA-F0-9]{40}/`")  # noqa: E501

        self._sha1 = sha1

    @property
    def sha256(self):
        """Gets the sha256 of this MagicReport.  # noqa: E501

        A SHA256 cryptographic hash  # noqa: E501

        :return: The sha256 of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this MagicReport.

        A SHA256 cryptographic hash  # noqa: E501

        :param sha256: The sha256 of this MagicReport.  # noqa: E501
        :type: str
        """
        if sha256 is not None and not re.search(r'[a-fA-F0-9]{64}', sha256):  # noqa: E501
            raise ValueError(r"Invalid value for `sha256`, must be a follow pattern or equal to `/[a-fA-F0-9]{64}/`")  # noqa: E501

        self._sha256 = sha256

    @property
    def sha512(self):
        """Gets the sha512 of this MagicReport.  # noqa: E501

        A SHA512 cryptographic hash  # noqa: E501

        :return: The sha512 of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._sha512

    @sha512.setter
    def sha512(self, sha512):
        """Sets the sha512 of this MagicReport.

        A SHA512 cryptographic hash  # noqa: E501

        :param sha512: The sha512 of this MagicReport.  # noqa: E501
        :type: str
        """
        if sha512 is not None and not re.search(r'[a-fA-F0-9]{128}', sha512):  # noqa: E501
            raise ValueError(r"Invalid value for `sha512`, must be a follow pattern or equal to `/[a-fA-F0-9]{128}/`")  # noqa: E501

        self._sha512 = sha512

    @property
    def md5(self):
        """Gets the md5 of this MagicReport.  # noqa: E501

        An MD5 cryptographic hash  # noqa: E501

        :return: The md5 of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this MagicReport.

        An MD5 cryptographic hash  # noqa: E501

        :param md5: The md5 of this MagicReport.  # noqa: E501
        :type: str
        """
        if md5 is not None and not re.search(r'[a-fA-F0-9]{32}', md5):  # noqa: E501
            raise ValueError(r"Invalid value for `md5`, must be a follow pattern or equal to `/[a-fA-F0-9]{32}/`")  # noqa: E501

        self._md5 = md5

    @property
    def unix_file_type(self):
        """Gets the unix_file_type of this MagicReport.  # noqa: E501

        Unix file type of the file.  # noqa: E501

        :return: The unix_file_type of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._unix_file_type

    @unix_file_type.setter
    def unix_file_type(self, unix_file_type):
        """Sets the unix_file_type of this MagicReport.

        Unix file type of the file.  # noqa: E501

        :param unix_file_type: The unix_file_type of this MagicReport.  # noqa: E501
        :type: str
        """

        self._unix_file_type = unix_file_type

    @property
    def object_class(self):
        """Gets the object_class of this MagicReport.  # noqa: E501

        An internal indicator of the type of object this file is.  # noqa: E501

        :return: The object_class of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._object_class

    @object_class.setter
    def object_class(self, object_class):
        """Sets the object_class of this MagicReport.

        An internal indicator of the type of object this file is.  # noqa: E501

        :param object_class: The object_class of this MagicReport.  # noqa: E501
        :type: str
        """

        self._object_class = object_class

    @property
    def filename(self):
        """Gets the filename of this MagicReport.  # noqa: E501

        The original file names associated with the file.  # noqa: E501

        :return: The filename of this MagicReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this MagicReport.

        The original file names associated with the file.  # noqa: E501

        :param filename: The filename of this MagicReport.  # noqa: E501
        :type: list[str]
        """

        self._filename = filename

    @property
    def first_seen(self):
        """Gets the first_seen of this MagicReport.  # noqa: E501

        Timestamp of when this file was first uploaded to MAGIC  # noqa: E501

        :return: The first_seen of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._first_seen

    @first_seen.setter
    def first_seen(self, first_seen):
        """Sets the first_seen of this MagicReport.

        Timestamp of when this file was first uploaded to MAGIC  # noqa: E501

        :param first_seen: The first_seen of this MagicReport.  # noqa: E501
        :type: str
        """

        self._first_seen = first_seen

    @property
    def is_owned(self):
        """Gets the is_owned of this MagicReport.  # noqa: E501

        Is this file owned by this user  # noqa: E501

        :return: The is_owned of this MagicReport.  # noqa: E501
        :rtype: bool
        """
        return self._is_owned

    @is_owned.setter
    def is_owned(self, is_owned):
        """Sets the is_owned of this MagicReport.

        Is this file owned by this user  # noqa: E501

        :param is_owned: The is_owned of this MagicReport.  # noqa: E501
        :type: bool
        """

        self._is_owned = is_owned

    @property
    def categories(self):
        """Gets the categories of this MagicReport.  # noqa: E501


        :return: The categories of this MagicReport.  # noqa: E501
        :rtype: MagicCategories
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this MagicReport.


        :param categories: The categories of this MagicReport.  # noqa: E501
        :type: MagicCategories
        """

        self._categories = categories

    @property
    def labels(self):
        """Gets the labels of this MagicReport.  # noqa: E501


        :return: The labels of this MagicReport.  # noqa: E501
        :rtype: list[MagicLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this MagicReport.


        :param labels: The labels of this MagicReport.  # noqa: E501
        :type: list[MagicLabel]
        """

        self._labels = labels

    @property
    def tags(self):
        """Gets the tags of this MagicReport.  # noqa: E501

        List of tags added to this binary.  # noqa: E501

        :return: The tags of this MagicReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this MagicReport.

        List of tags added to this binary.  # noqa: E501

        :param tags: The tags of this MagicReport.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def detection_stats(self):
        """Gets the detection_stats of this MagicReport.  # noqa: E501


        :return: The detection_stats of this MagicReport.  # noqa: E501
        :rtype: MagicReportDetectionStats
        """
        return self._detection_stats

    @detection_stats.setter
    def detection_stats(self, detection_stats):
        """Sets the detection_stats of this MagicReport.


        :param detection_stats: The detection_stats of this MagicReport.  # noqa: E501
        :type: MagicReportDetectionStats
        """

        self._detection_stats = detection_stats

    @property
    def av_names(self):
        """Gets the av_names of this MagicReport.  # noqa: E501

        List of names assigned to this binary by a Multi-Scanner.  # noqa: E501

        :return: The av_names of this MagicReport.  # noqa: E501
        :rtype: list[str]
        """
        return self._av_names

    @av_names.setter
    def av_names(self, av_names):
        """Sets the av_names of this MagicReport.

        List of names assigned to this binary by a Multi-Scanner.  # noqa: E501

        :param av_names: The av_names of this MagicReport.  # noqa: E501
        :type: list[str]
        """

        self._av_names = av_names

    @property
    def campaign_id(self):
        """Gets the campaign_id of this MagicReport.  # noqa: E501

        ID of the campaign this binary is in.  # noqa: E501

        :return: The campaign_id of this MagicReport.  # noqa: E501
        :rtype: str
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this MagicReport.

        ID of the campaign this binary is in.  # noqa: E501

        :param campaign_id: The campaign_id of this MagicReport.  # noqa: E501
        :type: str
        """

        self._campaign_id = campaign_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MagicReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MagicReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Cythereal MAGIC API

     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: `ff9790d7902fea4c910b182f6e0b00221a40d616`   * Can be used for `file_hash` parameters. * Procedure RVA: `0x1000`   * Use with the above SHA1 for `proc_rva` parameters.   # API Conventions  Properties MUST be named using `snake_case`.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type `APIResponse` and contain the following fields:  * `api_version` |  The current api version * `success` | Boolean value indicating if the operation succeeded. * `code` | Status code. Typically corresponds to the HTTP status code.  * `message` | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a `SuccessResponse`, which extends `APIResponse` by adding:  * `data` | Properties containing the response object. * `success` | MUST equal True  When returning objects from a successful response, the `data` object SHOULD contain a property named after the requested object type. For example, the `/matches` endpoint should return a response object with `data.matches`. This property SHOULD  contain a list of the returned objects. For the `/matches` endpoint, the `data.matches` property contains a list of MagicMatch objects. See the `/matches` endpoint documentation for an example.  **Failed Operations** MUST return an `ErrorResponse`, which extends `APIResponse` by adding:  * `errors` | Array of error objects. An error object contains the following properties:     * `ErrorObject.reason` | Unique identifier for this error. Example: \"FileNotFoundError\".     * `ErrorObject.message`| Human readable error message. * `success` | MUST equal False.   # noqa: E501

    OpenAPI spec version: 1
    Contact: support@cythereal.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "cythereal-magic"
VERSION = "1.24.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="Cythereal MAGIC API",
    author_email="support@cythereal.com",
    url="",
    keywords=["Swagger", "Cythereal MAGIC API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     The API for accessing Cythereal MAGIC products and services.  # API Clients  We provide clients in several languages for accessing the MAGIC API. https://bitbucket.org/cythereal/magic-clients  These clients are provided to make integration of the MAGIC API into your existing applications as easy as possible.  If you want to use a language that is not currently supported, please contact us at support@cythereal.com and we will be glad to help.  # Example Inputs  Here are some example inputs that can be used for testing the service:  * Binary SHA1: &#x60;ff9790d7902fea4c910b182f6e0b00221a40d616&#x60;   * Can be used for &#x60;file_hash&#x60; parameters. * Procedure RVA: &#x60;0x1000&#x60;   * Use with the above SHA1 for &#x60;proc_rva&#x60; parameters.   # API Conventions  Properties MUST be named using &#x60;snake_case&#x60;.  This API is inspired by the [google json style guide](https://google.github.io/styleguide/jsoncstyleguide.xml). Any questions about conventions not documented here should be addressed by this style guide.  **All responses** MUST be of type &#x60;APIResponse&#x60; and contain the following fields:  * &#x60;api_version&#x60; |  The current api version * &#x60;success&#x60; | Boolean value indicating if the operation succeeded. * &#x60;code&#x60; | Status code. Typically corresponds to the HTTP status code.  * &#x60;message&#x60; | A human readable message providing more details about the operation. Can be null or empty.  **Successful operations** MUST return a &#x60;SuccessResponse&#x60;, which extends &#x60;APIResponse&#x60; by adding:  * &#x60;data&#x60; | Properties containing the response object. * &#x60;success&#x60; | MUST equal True  When returning objects from a successful response, the &#x60;data&#x60; object SHOULD contain a property named after the requested object type. For example, the &#x60;/matches&#x60; endpoint should return a response object with &#x60;data.matches&#x60;. This property SHOULD  contain a list of the returned objects. For the &#x60;/matches&#x60; endpoint, the &#x60;data.matches&#x60; property contains a list of MagicMatch objects. See the &#x60;/matches&#x60; endpoint documentation for an example.  **Failed Operations** MUST return an &#x60;ErrorResponse&#x60;, which extends &#x60;APIResponse&#x60; by adding:  * &#x60;errors&#x60; | Array of error objects. An error object contains the following properties:     * &#x60;ErrorObject.reason&#x60; | Unique identifier for this error. Example: \&quot;FileNotFoundError\&quot;.     * &#x60;ErrorObject.message&#x60;| Human readable error message. * &#x60;success&#x60; | MUST equal False.   # noqa: E501
    """
)
